# NAPE Evaluator

The NAPE Evaluator (nape-eval) is a tool for applying a Test of Details against collected evidence for a Control Action.  This evaluator is a dependency for the NAPE CLI used to manage the evaluation of NAPE Assurance Procedures.